@@ -11,6 +11,7 @@ use Cwd;
 use File::Basename;
 use File::Which;
 use IPC::Run3 ();
+use constant DEBUG => $ENV{MOJO_ASSETPACK_DEBUG} || 0;
 
 our $VERSION = '0.01';
 
@@ -119,7 +120,6 @@ sub detect {
   my $self = shift;
 
   if(my $app = which('jsx')) {
-    $self->map_type(jsx => 'js');
     $self->add(jsx => sub {
       my($assetpack, $text, $file) = @_;
       $self->_run(['jsx'], $text, $text); # TODO: Add --follow-requires ?
@@ -127,14 +127,12 @@ sub detect {
     });
   }
   if(my $app = which('lessc')) {
-    $self->map_type(less => 'css');
     $self->add(less => sub {
       my($assetpack, $text, $file) = @_;
       $self->_run([$app, '-', $assetpack->minify ? ('-x') : ()], $text, $text);
     });
   }
   if(my $app = which('sass')) {
-    $self->map_type(scss => 'css');
     $self->add(scss => sub {
       my($assetpack, $text, $file) = @_;
       my @cmd = ( $app, '-I' => dirname $file );
@@ -145,7 +143,6 @@ sub detect {
 
       $self->_run(\@cmd, $text, $text);
     });
-    $self->map_type(sass => 'css');
     $self->add(sass => sub {
       my($assetpack, $text, $file) = @_;
       my $include_dir = dirname $file;
@@ -153,7 +150,6 @@ sub detect {
     });
   }
   if(my $app = which('coffee')) {
-    $self->map_type(coffee => 'js');
     $self->add(coffee => sub {
       my($assetpack, $text, $file) = @_;
       my $err;
@@ -212,21 +208,7 @@ sub process {
 
 =head2 map_type
 
-  $self = $self->map_type($from => $to);
-  $to = $self->map_type($from);
-
-Method used to map one file type that should be transformed to another file
-type. Example:
-
-  $self->map_type(coffee => "js");
-
-=cut
-
-sub map_type {
-  return $_[0]->{extensions}{$_[1]} || '' if @_ == 2;
-  $_[0]->{extensions}{$_[1]} = $_[2];
-  return $_[0];
-}
+DEPRECATED: The mapping is already done based on input files.
 
 =head2 remove
 
@@ -249,6 +231,7 @@ sub _js_minify {
 sub _run {
   my ($self, @args) = @_;
   local ($?, $@, $!);
+  warn "[ASSETPACK] \$ @{ $args[0] }\n" if DEBUG;
   eval { IPC::Run3::run3(@args); };
   return $self unless $?;
   chomp $@ if $@;
